@@ -65,7 +65,7 @@ DEFAULTS = {
     'PIPELINE_MIMETYPES': (
         (b'text/coffeescript', '.coffee'),
         (b'text/less', '.less'),
-        (b'application/javascript', '.js'),
+        (b'text/javascript', '.js'),
         (b'text/x-sass', '.sass'),
         (b'text/x-scss', '.scss')
     ),
