@@ -131,14 +131,19 @@ class BaseFinderStorage(PipelineStorage):
     def listdir(self, path):
         directories, files = [], []
         for finder in self.finders.get_finders():
-            for storage in finder.storages.values():
-                try:
-                    new_directories, new_files = storage.listdir(path)
-                except OSError:
-                    pass
-                else:
-                    directories.extend(new_directories)
-                    files.extend(new_files)
+            try:
+                storages = finder.storages.values()
+            except AttributeError:
+                continue
+            else:
+                for storage in storages:
+                    try:
+                        new_directories, new_files = storage.listdir(path)
+                    except OSError:
+                        pass
+                    else:
+                        directories.extend(new_directories)
+                        files.extend(new_files)
         return directories, files
 
     def find_storage(self, name):
